netapp_ontap.models.cluster_nodes API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.cluster_nodes`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ClusterNodesSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ClusterNodes object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `anti_ransomware_version: str GET`

    Anti ransomware version.

    Example: 1.0

  `cluster_interface: ClusterNodesClusterInterface POST`

    The cluster network IP address of the node to be added.

  `cluster_interfaces: List[IpInterface] GET`

    The cluster_interfaces field of the cluster_nodes.

  `controller: ClusterNodesController GET`

    Controller information

  `date: ImpreciseDateTime GET`

    The current or "wall clock" time of the node in ISO-8601 date, time, and time zone format. The ISO-8601 date and time are localized based on the ONTAP cluster's timezone setting.

    Example: 2019-04-17T15:49:26.000+0000

  `external_cache: ClusterNodesExternalCache GET`

    Cache used for buffer management.

  `external_cache_bypass: ClusterNodesExternalCacheBypass GET POST PATCH`

    External cache bypass management.

  `ha: ClusterNodesHa GET POST PATCH`

    The ha field of the cluster_nodes.

  `hw_assist: HwAssist GET`

    The hardware assist information.

  `is_spares_low: bool GET`

    Specifies whether or not the node is in spares low condition.

  `links: SelfLink GET`

    The links field of the cluster_nodes.

  `location: str GET POST PATCH`

    The location field of the cluster_nodes.

    Example: rack 2 row 5

  `management_interface: ClusterNodesManagementInterface POST`

    The management interface of the node to be added. The subnet mask is set based on the management interface of the cluster or the management interfaces of other nodes.

  `management_interfaces: List[IpInterface] GET`

    The management_interfaces field of the cluster_nodes.

  `membership: str GET`

    Possible values:

    - available - A node is detected on the internal cluster network and can be added to the cluster. Nodes that have a membership of "available" are not returned when a GET request is called when the cluster exists. Provide a query on the "membership" property for available to scan for nodes on the cluster network. Nodes that have a membership of "available" are returned automatically before a cluster is created.
    - joining - Joining nodes are in the process of being added to the cluster. The node might be progressing through the steps to become a member or might have failed. The job to add the node or create the cluster provides details on the current progress of the node.
    - member - Nodes that are members have successfully joined the cluster.

    Valid choices:

    - available
    - joining
    - member
  `metric: NodeMetrics GET`

    CPU performance for the nodes.

  `metrocluster: ClusterNodesMetrocluster GET`

    Metrocluster

  `model: str GET`

    The model field of the cluster_nodes.

    Example: FAS3070

  `name: str GET POST PATCH`

    The name field of the cluster_nodes.

    Example: node-01

  `nvlog: ClusterNodesNvlog GET POST PATCH`

    Non-volatile write log settings.

  `nvram: ClusterNodesNvram GET`

    The nvram field of the cluster_nodes.

  `owner: str GET POST PATCH`

    Owner of the node.

    Example: Example Corp

  `serial_number: str GET`

    The serial_number field of the cluster_nodes.

    Example: 4048820-60-9

  `service_processor: ServiceProcessor GET POST PATCH`

    The service_processor field of the cluster_nodes.

  `snaplock: ClusterNodesSnaplock GET`

    SnapLock-related properties.

  `state: str GET`

    State of the node:

    - up - Node is up and operational.
    - booting - Node is booting up.
    - down - Node has stopped or is dumping core.
    - taken_over - Node has been taken over by its HA partner and is not yet waiting for giveback.
    - waiting_for_giveback - Node has been taken over by its HA partner and is waiting for the HA partner to giveback disks.
    - degraded - Node has one or more critical services offline.
    - unknown - Node or its HA partner cannot be contacted and there is no information on the node's state.

    Valid choices:

    - up
    - booting
    - down
    - taken_over
    - waiting_for_giveback
    - degraded
    - unknown
  `statistics: NodeStatistics GET`

    Raw CPU performance for the nodes.

  `storage_availability_zones: List[StorageAvailabilityZone] GET`

    Storage availability zones associated with the node.

  `storage_configuration: str GET`

    The storage configuration in the system. Possible values:

    - mixed_path
    - single_path
    - multi_path
    - tri_path
    - quad_path
    - mixed_path_ha
    - single_path_ha
    - multi_path_ha
    - tri_path_ha
    - quad_path_ha
    - unknown
    - virtual

    Valid choices:

    - unknown
    - single_path
    - multi_path
    - mixed_path
    - quad_path
    - single_path_ha
    - multi_path_ha
    - mixed_path_ha
    - quad_path_ha
    - tri_path
    - tri_path_ha
    - virtual
  `system_aggregate: Aggregate GET POST PATCH`

    The system_aggregate field of the cluster_nodes.

  `system_id: str GET`

    The system_id field of the cluster_nodes.

    Example: 92027651

  `system_machine_type: str GET`

    OEM system machine type.

    Example: 7Y56-CTOWW1

  `uptime: Size GET`

    The total time, in seconds, that the node has been up.

    Example: 300536

  `uuid: str GET`

    The uuid field of the cluster_nodes.

    Example: 4ea7a442-86d1-11e0-ae1c-123478563412

  `vendor_serial_number: str GET`

    OEM vendor serial number.

    Example: 791603000068

  `version: Version GET`

    This returns the cluster version information. When the cluster has more than one node, the cluster version is equivalent to the lowest of generation, major, and minor versions on all nodes.

  `vm: ClusterNodesVm GET`

    The vm field of the cluster_nodes.